import { BaseApi } from './Base';
import { Buffer, AsyncBuffer } from './Buffer';
import { Tabpage, AsyncTabpage } from './Tabpage';
import { Window, AsyncWindow } from './Window';
export declare type UiAttachOptions = {
    rgb?: boolean;
    ext_popupmenu?: boolean;
    ext_tabline?: boolean;
    ext_wildmenu?: boolean;
    ext_cmdline?: boolean;
};
/**
 * Neovim API
 */
export declare class Neovim extends BaseApi {
    protected prefix: string;
    constructor(options: any);
    readonly buffers: Promise<Buffer[]>;
    buffer: AsyncBuffer;
    readonly tabpages: Promise<Tabpage[]>;
    tabpage: AsyncTabpage;
    readonly windows: Promise<Window[]>;
    window: AsyncWindow;
    readonly runtimePaths: Promise<Array<string>>;
    dir: string;
    line: string | Promise<string>;
    readonly mode: Promise<string>;
    readonly colorMap: Promise<any>;
    getColorByName(name: string): Promise<number>;
    deleteCurrentLine(): Promise<any>;
    eval(arg: any[]): Promise<any>;
    call(fname: string, args?: Array<any>): Promise<any>;
    callFunction(fname: string, args?: Array<any>): Promise<any>;
    callAtomic(calls: Array<string>): Promise<[Array<any>, boolean]>;
    command(arg: string): void;
    commandOutput(arg: string): Promise<string>;
    getVvar(name: string): Promise<string>;
    feedKeys(keys: string, mode: string, escapeCsi: boolean): Promise<any>;
    input(keys: string): Promise<number>;
    replaceTermcodes(str: string, fromPart: boolean, doIt: boolean, special: boolean): Promise<string>;
    strWidth(str: string): Promise<number>;
    outWrite(str: string): Promise<any>;
    errWrite(str: string): Promise<any>;
    errWriteLine(str: string): Promise<any>;
    uiAttach(width: number, height: number, options: UiAttachOptions): Promise<void>;
    uiDetach(): Promise<void>;
    uiTryResize(width: number, height: number): Promise<void>;
    uiSetOption(name: string, value: any): Promise<void>;
    subscribe(event: String): Promise<void>;
    unsubscribe(event: String): Promise<void>;
    quit(): void;
}
