"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Base_1 = require("./Base");
const createChainableApi_1 = require("./helpers/createChainableApi");
const Buffer_1 = require("./Buffer");
const Tabpage_1 = require("./Tabpage");
const Window_1 = require("./Window");
/**
 * Neovim API
 */
class Neovim extends Base_1.BaseApi {
    constructor(options) {
        super(options);
        this.prefix = '';
        this.prefix = 'nvim_';
    }
    // Buffer
    get buffers() {
        return this.request(`${this.prefix}list_bufs`);
    }
    get buffer() {
        return createChainableApi_1.createChainableApi.call(this, 'Buffer', Buffer_1.Buffer, () => this.request(`${this.prefix}get_current_buf`));
    }
    set buffer(buffer) {
        this.request(`${this.prefix}set_current_buf`, [buffer]);
    }
    // TabPage
    get tabpages() {
        return this.request(`${this.prefix}list_tabpages`);
    }
    get tabpage() {
        return createChainableApi_1.createChainableApi.call(this, 'Tabpage', Tabpage_1.Tabpage, () => this.request(`${this.prefix}get_current_tabpage`));
    }
    set tabpage(tabpage) {
        this.request(`${this.prefix}set_current_tabpage`, [tabpage]);
    }
    get windows() {
        return this.request(`${this.prefix}list_wins`);
    }
    get window() {
        return createChainableApi_1.createChainableApi.call(this, 'Window', Window_1.Window, () => this.request(`${this.prefix}get_current_win`));
    }
    set window(win) {
        // Throw error if win is not instance of Window?
        this.request(`${this.prefix}set_current_win`, [win]);
    }
    get runtimePaths() {
        return this.request(`${this.prefix}list_runtime_paths`);
    }
    set dir(dir) {
        this.request(`${this.prefix}set_current_dir`, [dir]);
    }
    // Get current line
    get line() {
        return this.request(`${this.prefix}get_current_line`);
    }
    // Set current line
    set line(line) {
        this.request(`${this.prefix}set_current_line`, [line]);
    }
    get mode() {
        return this.request(`${this.prefix}get_mode`);
    }
    get colorMap() {
        return this.request(`${this.prefix}get_color_map`);
    }
    // (name: string): number
    getColorByName(name) {
        return this.request(`${this.prefix}get_color_by_name`, [name]);
    }
    deleteCurrentLine() {
        return this.request(`${this.prefix}del_current_line`);
    }
    eval(arg) {
        return this.request(`${this.prefix}eval`, [arg]);
    }
    call(fname, args = []) {
        return this.request(`${this.prefix}call_function`, [fname, args]);
    }
    callFunction(fname, args = []) {
        return this.call(fname, args);
    }
    // (calls: Array<string>): [Array<any>, boolean]
    callAtomic(calls) {
        return this.request(`${this.prefix}call_atomic`, [calls]);
    }
    command(arg) {
        this.request(`${this.prefix}command`, [arg]);
    }
    // TODO: Documentation
    commandOutput(arg) {
        return this.request(`${this.prefix}command_output`, [arg]);
    }
    // Gets a v: variable
    getVvar(name) {
        return this.request(`${this.prefix}get_vvar`, [name]);
    }
    // (keys: string, mode: string, escapeCsi: boolean): void
    feedKeys(keys, mode, escapeCsi) {
        return this.request(`${this.prefix}feedkeys`, [keys, mode, escapeCsi]);
    }
    // (keys: string): number
    input(keys) {
        return this.request(`${this.prefix}input`, [keys]);
    }
    // (str: string, fromPart: boolean, doIt: boolean, special: boolean): string
    replaceTermcodes(str, fromPart, doIt, special) {
        return this.request(`${this.prefix}replace_termcodes`, [
            str,
            fromPart,
            doIt,
            special,
        ]);
    }
    // (str: string): number
    strWidth(str) {
        return this.request(`${this.prefix}strwidth`, [str]);
    }
    // (str: string)
    outWrite(str) {
        return this.request(`${this.prefix}out_write`, [str]);
    }
    // (str: string)
    errWrite(str) {
        return this.request(`${this.prefix}err_write`, [str]);
    }
    // (str: string)
    errWriteLine(str) {
        return this.request(`${this.prefix}err_writeln`, [str]);
    }
    uiAttach(width, height, options) {
        return this.request(`${this.prefix}ui_attach`, [width, height, options]);
    }
    uiDetach() {
        return this.request(`${this.prefix}ui_detach`, []);
    }
    uiTryResize(width, height) {
        return this.request(`${this.prefix}ui_try_resize`, [width, height]);
    }
    uiSetOption(name, value) {
        return this.request(`${this.prefix}ui_set_option`, [name, value]);
    }
    subscribe(event) {
        return this.request(`${this.prefix}subscribe`, [event]);
    }
    unsubscribe(event) {
        return this.request(`${this.prefix}unsubscribe`, [event]);
    }
    // Extra API methods
    quit() {
        this.command('qa!');
    }
}
exports.Neovim = Neovim;
